@@ -3,20 +3,9 @@
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -63,7 +52,7 @@ typedef struct _GUPnPServiceInfoPrivate GUPnPServiceInfoPrivate;
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GUPnPServiceInfo,
                                      gupnp_service_info,
-                                     G_TYPE_OBJECT);
+                                     G_TYPE_OBJECT)
 
 enum {
         PROP_0,
@@ -694,7 +683,7 @@ introspection_error_cb (gpointer user_data)
  *
  * Note that introspection object is created from the information in service
  * description document (SCPD) provided by the service so it can not be created
- * if the service does not provide an SCPD.
+ * if the service does not provide a SCPD.
  **/
 void
 gupnp_service_info_get_introspection_async
@@ -717,7 +706,7 @@ gupnp_service_info_get_introspection_async
  *
  * Note that introspection object is created from the information in service
  * description document (SCPD) provided by the service so it can not be created
- * if the service does not provide an SCPD.
+ * if the service does not provide a SCPD.
  *
  * If @cancellable is used to cancel the call, @callback will be called with
  * error code %G_IO_ERROR_CANCELLED.
@@ -828,13 +817,13 @@ prv_introspection_cb (GUPnPServiceInfo *info,
 /**
  * gupnp_service_info_introspect_async:
  * @info: A #GUPnPServiceInfo
- * @cancellable: (allow-none) : #GCancellable that can be used to cancel the call, or %NULL.
+ * @cancellable: (nullable) : #GCancellable that can be used to cancel the call, or %NULL.
  * @callback: (scope async) : callback to be called when introspeciton object is ready.
  * @user_data: user_data to be passed to the callback.
  *
  * Note that introspection object is created from the information in service
  * description document (SCPD) provided by the service so it can not be created
- * if the service does not provide an SCPD.
+ * if the service does not provide a SCPD.
  *
  * If @cancellable is used to cancel the call, @callback will be called with
  * error code %G_IO_ERROR_CANCELLED.
@@ -848,6 +837,7 @@ gupnp_service_info_introspect_async           (GUPnPServiceInfo    *info,
                                                gpointer             user_data)
 {
         GTask *task = g_task_new (info, cancellable, callback, user_data);
+        g_task_set_name (task, "UPnP service introspection");
 
         gupnp_service_info_get_introspection_async_full (info,
                                                          prv_introspection_cb,
@@ -859,12 +849,12 @@ gupnp_service_info_introspect_async           (GUPnPServiceInfo    *info,
  * gupnp_service_info_introspect_finish:
  * @info: A GUPnPServiceInfo
  * @res: A #GAsyncResult
- * @error: (allow-none): Return location for a #GError, or %NULL
+ * @error: (inout)(optional)(nullable): Return location for a #GError, or %NULL
  *
  * Finish an asynchronous call initiated with
  * gupnp_service_info_introspect_async().
  *
- * Returns: (transfer full): %NULL, if the call had an error, a
+ * Returns: (nullable)(transfer full): %NULL, if the call had an error, a
  * #GUPnPServiceIntrospection object otherwise.
  *
  * Since: 1.2.2
