@@ -5,20 +5,8 @@
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *         Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -34,7 +22,7 @@
  *
  * Note that all the introspection information is retreived from the service
  * description document (SCPD) provided by the service and hence can not be
- * guaranteed to be complete. A UPnP service is required to provide an SCPD but
+ * guaranteed to be complete. A UPnP service is required to provide a SCPD but
  * unfortunately, many services either do not provide this document or the
  * document does not provide any or all of the introspection information.
  *
@@ -74,7 +62,7 @@ typedef struct _GUPnPServiceIntrospectionPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (GUPnPServiceIntrospection,
                             gupnp_service_introspection,
-                            G_TYPE_OBJECT);
+                            G_TYPE_OBJECT)
 enum {
         PROP_0,
         PROP_SCPD
@@ -750,7 +738,7 @@ collect_variable_names (gpointer data,
 
 /**
  * gupnp_service_introspection_new:
- * @scpd: Pointer to the SCPD of the service to create a introspection for
+ * @scpd: Pointer to the SCPD of the service to create an introspection for
  *
  * Create a new #GUPnPServiceIntrospection for the service created from the
  * SCPD @scpd or %NULL.
@@ -897,7 +885,7 @@ state_variable_search_func (GUPnPServiceStateVariableInfo *variable,
  *
  * Returns the state variable by the name @variable_name in this service.
  *
- * Return value: (transfer none)(allow-none): the state variable or %NULL. Do not modify or
+ * Return value: (transfer none)(nullable): the state variable or %NULL. Do not modify or
  * free it.
  **/
 const GUPnPServiceStateVariableInfo *
@@ -937,7 +925,7 @@ action_search_func (GUPnPServiceActionInfo *action,
  *
  * Returns the action by the name @action_name in this service.
  *
- * Return value: (transfer none)(allow-none): the action or %NULL. Do not modify or free
+ * Return value: (transfer none)(nullable): the action or %NULL. Do not modify or free
  * it.
  **/
 const GUPnPServiceActionInfo *
