@@ -5,52 +5,28 @@
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *         Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __GUPNP_SERVICE_INTROSPECTION_H__
-#define __GUPNP_SERVICE_INTROSPECTION_H__
+#ifndef GUPNP_SERVICE_INTROSPECTION_H
+#define GUPNP_SERVICE_INTROSPECTION_H
 
 #include <glib-object.h>
 
 G_BEGIN_DECLS
 
-GType
-gupnp_service_introspection_get_type (void) G_GNUC_CONST;
-
 #define GUPNP_TYPE_SERVICE_INTROSPECTION \
                 (gupnp_service_introspection_get_type ())
-#define GUPNP_SERVICE_INTROSPECTION(obj) \
-                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                 GUPNP_TYPE_SERVICE_INTROSPECTION, \
-                 GUPnPServiceIntrospection))
-#define GUPNP_SERVICE_INTROSPECTION_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_CAST ((obj), \
-                 GUPNP_TYPE_SERVICE_INTROSPECTION, \
-                 GUPnPServiceIntrospectionClass))
-#define GUPNP_IS_SERVICE_INTROSPECTION(obj) \
-                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                 GUPNP_TYPE_SERVICE_INTROSPECTION))
-#define GUPNP_IS_SERVICE_INTROSPECTION_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_TYPE ((obj), \
-                 GUPNP_TYPE_SERVICE_INTROSPECTION))
-#define GUPNP_SERVICE_INTROSPECTION_GET_CLASS(obj) \
-                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-                 GUPNP_TYPE_SERVICE_INTROSPECTION, \
-                 GUPnPServiceIntrospectionClass))
+
+#define GUPNP_TYPE_SERVICE_ACTION_INFO (gupnp_service_action_info_get_type())
+#define GUPNP_TYPE_SERVICE_ACTION_ARG_INFO (gupnp_service_action_arg_info_get_type())
+
+
+G_DECLARE_FINAL_TYPE (GUPnPServiceIntrospection,
+                      gupnp_service_introspection,
+                      GUPNP,
+                      SERVICE_INTROSPECTION,
+                      GObject)
 
 /**
  * GUPnPServiceActionArgDirection:
@@ -81,6 +57,8 @@ typedef struct {
         char                          *related_state_variable;
         gboolean                       retval;
 } GUPnPServiceActionArgInfo;
+GType
+gupnp_service_action_arg_info_get_type (void);
 
 /**
  * GUPnPServiceActionInfo:
@@ -95,6 +73,9 @@ typedef struct {
         GList *arguments; /* list of #GUPnPServiceActionArgInfo */
 } GUPnPServiceActionInfo;
 
+GType
+gupnp_service_action_info_get_type (void);
+
 /**
  * GUPnPServiceStateVariableInfo:
  * @name: The name of the state variable.
@@ -127,28 +108,8 @@ typedef struct {
         GList   *allowed_values;
 } GUPnPServiceStateVariableInfo;
 
-typedef struct _GUPnPServiceIntrospectionPrivate
-                GUPnPServiceIntrospectionPrivate;
-typedef struct _GUPnPServiceIntrospection
-                GUPnPServiceIntrospection;
-typedef struct _GUPnPServiceIntrospectionClass
-                GUPnPServiceIntrospectionClass;
-
-/**
- * GUPnPServiceIntrospection:
- *
- * This struct contains private data only, and should be accessed using the
- * functions below.
- */
-struct _GUPnPServiceIntrospection {
-        GObject parent;
-
-        GUPnPServiceIntrospectionPrivate *priv;
-};
-
-struct _GUPnPServiceIntrospectionClass {
-        GObjectClass parent_class;
-};
+GType
+gupnp_service_state_variable_info_get_type (void);
 
 const GList *
 gupnp_service_introspection_list_action_names
@@ -178,4 +139,4 @@ gupnp_service_introspection_get_state_variable
 
 G_END_DECLS
 
-#endif /* __GUPNP_SERVICE_INTROSPECTION_H__ */
+#endif /* GUPNP_SERVICE_INTROSPECTION_H */
