@@ -365,7 +365,9 @@ gupnp_service_action_get (GUPnPServiceAction *action,
         g_return_if_fail (action != NULL);
 
         va_start (var_args, action);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gupnp_service_action_get_valist (action, var_args);
+        G_GNUC_END_IGNORE_DEPRECATIONS
         va_end (var_args);
 }
 
@@ -557,7 +559,9 @@ gupnp_service_action_set (GUPnPServiceAction *action,
         g_return_if_fail (action != NULL);
 
         va_start (var_args, action);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gupnp_service_action_set_valist (action, var_args);
+        G_GNUC_END_IGNORE_DEPRECATIONS
         va_end (var_args);
 }
 
@@ -690,9 +694,22 @@ gupnp_service_action_set_value (GUPnPServiceAction *action,
  * @action: A #GUPnPServiceAction
  *
  * Return succesfully.
+ * Deprecated: 1.4.2: Use gupnp_service_action_return_success() instead
  **/
 void
 gupnp_service_action_return (GUPnPServiceAction *action)
+{
+        gupnp_service_action_return_success (action);
+}
+
+/**
+ * gupnp_service_action_return_success:
+ * @action: A #GUPnPServiceAction
+ *
+ * Return succesfully.
+ **/
+void
+gupnp_service_action_return_success (GUPnPServiceAction *action)
 {
         g_return_if_fail (action != NULL);
 
@@ -898,7 +915,7 @@ query_state_variable (GUPnPService       *service,
                 xmlFree (var_name);
         }
 
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 }
 
 /* controlURL handler */
@@ -1872,7 +1889,9 @@ gupnp_service_notify (GUPnPService *service,
         g_return_if_fail (GUPNP_IS_SERVICE (service));
 
         va_start (var_args, service);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gupnp_service_notify_valist (service, var_args);
+        G_GNUC_END_IGNORE_DEPRECATIONS
         va_end (var_args);
 }
 
